# OPS11-BP03: Define drivers for improvement

## Description

Xác định drivers cho improvement (metrics, incidents, feedback).

## Implementation Guidance

- Incident-driven improvements
- Metrics-driven improvements
- Customer feedback drivers
- Cost optimization drivers
- Security vulnerability drivers

## Risk Level

Low - Unknown drivers lead to unfocused improvement.
